Index: main/manager.c
===================================================================
--- main/manager.c	(revision 363268)
+++ main/manager.c	(working copy)
@@ -877,6 +877,19 @@
                         manager.conf will be present upon starting a new session.</para>
 		</description>
 	</manager>
+	<function name="MANAGER_ONLINE" language="en_US">
+		<synopsis>
+			Determine if anyone is connected to AMI as the specified username.
+		</synopsis>
+		<syntax>
+			<parameter name="username" required="true">
+				<para>Username to check</para>
+			</parameter>
+		</syntax>
+		<description>
+			<para>Return 1 if <replaceable>username</replaceable> has any active AMI sessions, 0 otherwise.</para>
+		</description>
+	</function>
  ***/
 
 enum error_type {
@@ -6763,6 +6776,20 @@
 	AST_CLI_DEFINE(handle_manager_show_settings, "Show manager global settings"),
 };
 
+static int acf_manager_online_exec(struct ast_channel *chan, const char *function, char *data, char *buf, size_t len) {
+	if(len<2)
+		return -1;
+	snprintf(buf, len, "%d", check_manager_session_inuse(data) > 0 ? 1 : 0);
+	return 0;
+}
+
+static struct ast_custom_function acf_manager_online = {
+	.name = "MANAGER_ONLINE",
+	.read = acf_manager_online_exec,
+	.read_max = 2
+};
+
+
 /*!
  * \internal
  * \brief Load the config channelvars variable.
@@ -6853,6 +6880,7 @@
 		ast_manager_register_xml_core("ModuleCheck", EVENT_FLAG_SYSTEM, manager_modulecheck);
 		ast_manager_register_xml_core("AOCMessage", EVENT_FLAG_AOC, action_aocmessage);
 		ast_manager_register_xml_core("Filter", EVENT_FLAG_SYSTEM, action_filter);
+		__ast_custom_function_register(&acf_manager_online, NULL);
 
 		ast_cli_register_multiple(cli_manager, ARRAY_LEN(cli_manager));
 		ast_extension_state_add(NULL, NULL, manager_state_cb, NULL);
